Description Usage Format Source
description
1 |
A data frame with 20 observations (rows) and 8 variables (columns). Each row is a day when the sample was measured.
A numeric column with the day when the sample was measured
A numeric column with the biological oxygen demand
A numeric column with the total Kjeldahl nitrogen
A numeric column with the total solids
A numeric column with the total volatile solids
A numeric column with the chemical oxygen demand
A numeric column with the oxygen uptake
A numeric column with the log transformation of the o2up variable
Dataset was published in Moore (1975) and reported in Weisberg (1985)
This data was pulled from StatLib (http://lib.stat.cmu.edu/datasets/alr) under the name alr222.
Column descriptions from Weisberg (1985).
Moore, J. A. (1975). Total biochemical oxygen demand of animal manures. University of Minnesota. Weisberg, Sanford. (1985). Applied linear regression. New York: Wiley.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.